@@ -29,7 +29,6 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
-#include <panel-applet-gconf.h>
 #include <X11/XKBlib.h>
 #define XK_MISCELLANY
 #define XK_XKB_KEYS
@@ -153,7 +152,7 @@ help_cb (GtkAction           *action,
 	GError *error = NULL;
 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)),
-			"ghelp:accessx-status",
+			"help:accessx-status",
 			gtk_get_current_event_time (),
 			&error);
 
