@@ -27,22 +27,17 @@
 static gboolean
 gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
-	GWeatherApplet *gw_applet;
+	GWeatherApplet *gw_applet = g_new0(GWeatherApplet, 1);
 
-	char *prefs_key = panel_applet_get_preferences_key(applet);
-
-	gw_applet = g_new0(GWeatherApplet, 1);   
-	
 	gw_applet->applet = applet;
 	gw_applet->gweather_info = NULL;
 	gw_applet->lib_settings = g_settings_new("org.gnome.GWeather");
-	gw_applet->applet_settings = panel_applet_settings_new(applet, "org.gnome.applets.GWeatherApplet");
-	g_free (prefs_key);
-    	gweather_applet_create(gw_applet);
+	gw_applet->applet_settings = panel_applet_settings_new(applet, "org.gnome.gnome-applets.gweather");
 
-    	gweather_update(gw_applet);
+	gweather_applet_create(gw_applet);
+	gweather_update(gw_applet);
 
-    	return TRUE;
+	return TRUE;
 }
 
 static gboolean
