@@ -1030,7 +1030,7 @@ on_modem_applet_help_clicked (GtkAction   *action,
 			      ModemApplet *applet)
 {
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
-		"ghelp:modemlights",
+		"help:modemlights",
 		gtk_get_current_event_time (),
 		NULL);
 }
