@@ -51,6 +51,7 @@ typedef struct
   gint items;
 } TrashApplet;
 
+GType trash_applet_get_type (void);
 G_DEFINE_TYPE (TrashApplet, trash_applet, PANEL_TYPE_APPLET);
 #define TRASH_TYPE_APPLET (trash_applet_get_type ())
 #define TRASH_APPLET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
@@ -374,7 +375,7 @@ trash_applet_open_folder (GtkAction   *action,
 
   if (err)
     {
-      error_dialog (applet, _("Error while spawning nautilus:\n%s"),
+      error_dialog (applet, _("Error while spawning Nautilus:\n%s"),
       err->message);
       g_error_free (err);
     }
@@ -388,7 +389,7 @@ trash_applet_show_help (GtkAction   *action,
 
   /* FIXME - Actually, we need a user guide */
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
-                "ghelp:trashapplet",
+                "help:trashapplet",
                 gtk_get_current_event_time (),
                 &err);
 
